Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Scheme defines methods for serializing and deserializing API objects. Scheme = runtime.NewScheme() // Codecs provides methods for retrieving codecs and serializers for specific // versions and content types. Codecs = serializer.NewCodecFactory(Scheme) )
Functions ¶
Types ¶
type CompletedConfig ¶
type CompletedConfig struct {
// contains filtered or unexported fields
}
CompletedConfig embeds a private pointer that cannot be instantiated outside of this package.
type Config ¶
type Config struct {
GenericConfig *genericapiserver.RecommendedConfig
ExtraConfig ExtraConfig
}
Config defines the config for the apiserver
func (*Config) Complete ¶
func (cfg *Config) Complete() CompletedConfig
Complete fills in any fields not set that are required to have valid data. It's mutating the receiver.
type ExtraConfig ¶
type ExtraConfig struct {
CoreAPIKubeconfigPath string
GRPCRuntimeOptions engine.GRPCRuntimeOptions
CacheOptions cachetypes.CacheOptions
}
ExtraConfig holds custom apiserver config
type PorchServer ¶
type PorchServer struct {
GenericAPIServer *genericapiserver.GenericAPIServer
// contains filtered or unexported fields
}
PorchServer contains state for a Kubernetes cluster master/api server.
type WebhookConfig ¶
type WebhookConfig struct {
Port int32
RepositoryPath string
RepoServiceName string
RepoServiceNamespace string
RepoHost string
CertStorageDir string
CertManWebhook bool
// contains filtered or unexported fields
}
WebhookConfig defines the configuration for the Repository validation webhook
Click to show internal directories.
Click to hide internal directories.