pull

package
v1.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2026 License: Apache-2.0 Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCommand

NewCommand returns the cobra command for `rpkg pull`, which fetches the resources of a package revision and writes them to a local directory or stdout for inspection or editing.

Types

This section is empty.

Jump to